@@ -1,5 +1,5 @@
 from django.utils.cache import get_conditional_response
-from django.utils.http import http_date, parse_http_date_safe
+from django.utils.http import http_date, parse_http_date_safe, unquote_etag
 
 
 class ConditionalGetMiddleware(object):
@@ -23,7 +23,7 @@ class ConditionalGetMiddleware(object):
         if etag or last_modified:
             return get_conditional_response(
                 request,
-                etag=etag,
+                etag=unquote_etag(etag),
                 last_modified=last_modified,
                 response=response,
             )
